@@ -109,7 +109,7 @@ class UserProfileIpExistsResponseContract(Contract):
 
 
 class SetCreditScoreCreateContract(Contract):
-    profile = serializers.IntegerField(min_value=1)
+    pass
 
 
 class RussianProfileID(ID):
